@@ -8,6 +8,7 @@
 #' @param df a data frame.
 #' @param y Quoted name of the variable representing the observed values in the data frame. If a data frame is not provided, \code{y} can also be a numeric vector.
 #' @param yhat Quoted name of the variable representing the estimated values in the data frame. If a data frame is not provided, \code{yhat} can also be a numeric vector.
+#' @param na.rm a logical value indicating whether NA values should be stripped before the computation proceeds. default: \code{TRUE}
 #' @return Numeric vector with the RMSE value, in percentage.
 #' 
 #' @keywords Root-Mean-Square-Error
@@ -29,11 +30,15 @@
 #' @author Sollano Rabelo Braga \email{sollanorb@@gmail.com}
 
 
-rmse_per <- function(df, y, yhat){
+rmse_per <- function(df, y, yhat, na.rm = TRUE){
   # Checagem de variaveis ####
   
   if(missing(df) & !missing(y) & !missing(yhat) ){
-    return( 100 * mean(y)^-1 * sqrt( mean( (y - yhat)^2 ) ) )
+    
+    df <- data.frame("y"=y,"yhat"=yhat)
+    y <- "y"
+    yhat <- "yhat"
+    
   }else if(  missing(df) ){  
     stop("df not set", call. = F) 
   }else if(!is.data.frame(df)){
@@ -69,6 +74,8 @@ rmse_per <- function(df, y, yhat){
   
   # ####
   
+  if(na.rm==TRUE) df <- df %>% dplyr::select(!!y_sym, !!yhat_sym) %>% stats::na.omit()
+  
   y <- df %>% dplyr::pull(!!y_sym)
   yhat <- df %>% dplyr::pull(!!yhat_sym)
   
